pub enum UpdatePhase {
NoUpdate,
Prepare,
Replace,
Cleanup,
}Expand description
The phase of the three-phase update process which an UpdateState is in.
The update is driven forward by relaunching the application between phases,
passing a serialized UpdateState each time (see
RESUME_FLAG). Each phase runs from a different
binary so that the running executable is never asked to overwrite itself.
Variants
NoUpdate
No update is in progress (the default, used when resuming with no state).
Prepare
The original application has downloaded the new binary and is about to
launch it to perform the replace phase.
Replace
The freshly downloaded binary overwrites the original application and
launches it to perform the cleanup phase.
Cleanup
The updated original application removes the temporary downloaded binary.