pub struct UpdateState {
pub target_application: Option<PathBuf>,
pub temporary_application: Option<PathBuf>,
pub phase: UpdatePhase,
}Expand description
The serializable state which is threaded through the three phases of an
update by relaunching the application with the
RESUME_FLAG followed by this value as JSON.
Fields
target_application: Option<PathBuf>The path to the application binary which is being updated.
temporary_application: Option<PathBuf>The path to the temporary binary which the new release was downloaded to.
phase: UpdatePhaseThe phase of the update process which this state represents.
Implementations
Sourceimpl UpdateState
impl UpdateState
Sourcepub fn for_phase(&self, phase: UpdatePhase) -> Self
pub fn for_phase(&self, phase: UpdatePhase) -> Self
Produce a copy of this state advanced to the provided UpdatePhase,
preserving the application paths.